@@ -1,41 +1,24 @@
-from typing import List, Optional
-from functools import partial
 import warnings
+from functools import partial
+from typing import List, Optional
 
 import xarray as xr
+
 try:
     import cupy
 except ImportError:
     class cupy(object):
         ndarray = False
 
-import datashader.transfer_functions as tf
-import numpy as np
-from datashader.colors import rgb
-
-import numba as nb
 import dask.array as da
+import numba as nb
+import numpy as np
 
-from numpy.random import RandomState
-
-from xrspatial.utils import cuda_args
-from xrspatial.utils import ngjit
-from xrspatial.utils import ArrayTypeFunctionMapping
-from xrspatial.utils import not_implemented_func
-
-
-def color_values(agg, color_key, alpha=255):
-    def _convert_color(c):
-        r, g, b = rgb(c)
-        return np.array([r, g, b, alpha]).astype(np.uint8).view(np.uint32)[0]
-
-    _converted_colors = {k: _convert_color(v) for k, v in color_key.items()}
-    f = np.vectorize(lambda v: _converted_colors.get(v, 0))
-    return tf.Image(f(agg.data))
+from xrspatial.utils import ArrayTypeFunctionMapping, cuda_args, ngjit, not_implemented_func
 
 
 @ngjit
-def _binary(data, values):
+def _cpu_binary(data, values):
     out = np.zeros_like(data)
     rows, cols = data.shape
     for y in range(0, rows):
@@ -47,14 +30,103 @@ def _binary(data, values):
     return out
 
 
+def _run_numpy_binary(data, values):
+    values = np.asarray(values)
+    out = _cpu_binary(data, values)
+    return out
+
+
+def _run_dask_numpy_binary(data, values):
+    _func = partial(_run_numpy_binary, values=values)
+    out = data.map_blocks(_func)
+    return out
+
+
+@nb.cuda.jit(device=True)
+def _gpu_binary(data, values):
+    val = data[0, 0]
+    for v in values:
+        if val == v:
+            return 1
+    return 0
+
+
+@nb.cuda.jit
+def _run_gpu_binary(data, values, out):
+    i, j = nb.cuda.grid(2)
+    if i >= 0 and i < out.shape[0] and j >= 0 and j < out.shape[1]:
+        out[i, j] = _gpu_binary(data[i:i+1, j:j+1], values)
+
+
+def _run_cupy_binary(data, values):
+    values_cupy = cupy.asarray(values)
+    out = cupy.empty(data.shape, dtype='f4')
+    out[:] = cupy.nan
+    griddim, blockdim = cuda_args(data.shape)
+    _run_gpu_binary[griddim, blockdim](data, values_cupy, out)
+    return out
+
+
+def _run_dask_cupy_binary(data, values_cupy):
+    out = data.map_blocks(lambda da: _run_cupy_binary(da, values_cupy), meta=cupy.array(()))
+    return out
+
+
 def binary(agg, values, name='binary'):
+    """
+    Binarize a data array based on a set of values. Data that equals to a value in the set will be
+    set to 1. In contrast, data that does not equal to any value in the set will be set to 0.
 
-    if isinstance(values, (list, tuple)):
-        vals = np.array(values)
-    else:
-        vals = values
+    Parameters
+    ----------
+    agg : xarray.DataArray
+        2D NumPy, CuPy, NumPy-backed Dask, or Cupy-backed Dask array
+        of values to be reclassified.
+    values : array-like object
+        Values to keep in the binarized array.
+    name : str, default='binary'
+        Name of output aggregate array.
 
-    return xr.DataArray(_binary(agg.data, vals),
+    Returns
+    -------
+    binarized_agg : xarray.DataArray, of the same type as `agg`
+        2D aggregate array of binarized data array.
+        All other input attributes are preserved.
+
+    Examples
+    --------
+    Binary works with NumPy backed xarray DataArray
+
+    .. sourcecode:: python
+
+        >>> import numpy as np
+        >>> import xarray as xr
+        >>> from xrspatial.classify import binary
+
+        >>> data = np.array([
+            [np.nan,  1.,  2.,  3.,  4.],
+            [5.,  6.,  7.,  8.,  9.],
+            [10., 11., 12., 13., 14.],
+            [15., 16., 17., 18., np.inf],
+        ], dtype=np.float32)
+        >>> agg = xr.DataArray(data)
+        >>> values = [1, 2, 3]
+        >>> agg_binary = binary(agg, values)
+        >>> print(agg_binary)
+        <xarray.DataArray 'binary' (dim_0: 4, dim_1: 5)>
+        array([[0.,  1.,  1.,  1.,  0.],
+               [0.,  0.,  0.,  0.,  0.],
+               [0.,  0.,  0.,  0.,  0.],
+               [0.,  0.,  0.,  0.,  0.]], dtype=float32)
+        Dimensions without coordinates: dim_0, dim_1
+    """
+
+    mapper = ArrayTypeFunctionMapping(numpy_func=_run_numpy_binary,
+                                      dask_func=_run_dask_numpy_binary,
+                                      cupy_func=_run_cupy_binary,
+                                      dask_cupy_func=_run_dask_cupy_binary)
+    out = mapper(agg)(agg.data, values)
+    return xr.DataArray(out,
                         name=name,
                         dims=agg.dims,
                         coords=agg.coords,
@@ -78,11 +150,13 @@ def _cpu_bin(data, bins, new_values):
                 # first bin
                 if b == 0:
                     if val <= bins[b]:
-                        val_bin = b
+                        if np.isfinite(val):
+                            val_bin = b
                         break
                 else:
                     if val > bins[b - 1] and val <= bins[b]:
-                        val_bin = b
+                        if np.isfinite(val):
+                            val_bin = b
                         break
 
             if val_bin > -1:
@@ -144,6 +218,10 @@ def _run_gpu_bin(data, bins, new_values, out):
 
 
 def _run_cupy_bin(data, bins, new_values):
+    # replace inf by nan to avoid classify these values as we want to treat them as outliers
+    data = cupy.where(data == cupy.inf, cupy.nan, data)
+    data = cupy.where(data == -cupy.inf, cupy.nan, data)
+
     bins_cupy = cupy.asarray(bins)
     new_values_cupy = cupy.asarray(new_values)
     out = cupy.empty(data.shape, dtype='f4')
@@ -207,6 +285,7 @@ def reclassify(agg: xr.DataArray,
     --------
     Reclassify works with NumPy backed xarray DataArray
     .. sourcecode:: python
+
         >>> import numpy as np
         >>> import xarray as xr
         >>> from xrspatial.classify import reclassify
@@ -238,6 +317,7 @@ def reclassify(agg: xr.DataArray,
 
     Reclassify works with Dask with NumPy backed xarray DataArray
     .. sourcecode:: python
+
         >>> import dask.array as da
         >>> data_da = da.from_array(data, chunks=(3, 3))
         >>> agg_da = xr.DataArray(data_da, name='agg_da')
@@ -261,6 +341,7 @@ def reclassify(agg: xr.DataArray,
     Reclassify works with CuPy backed xarray DataArray.
     Make sure you have a GPU and CuPy installed to run this example.
     .. sourcecode:: python
+
         >>> import cupy
         >>> data_cupy = cupy.asarray(data)
         >>> agg_cupy = xr.DataArray(data_cupy)
@@ -357,6 +438,7 @@ def quantile(agg: xr.DataArray,
     --------
     Quantile work with numpy backed xarray DataArray
     .. sourcecode:: python
+
         >>> import numpy as np
         >>> import xarray as xr
         >>> from xrspatial.classify import quantile
@@ -538,12 +620,17 @@ def _run_jenks(data, n_classes, module):
 def _run_natural_break(agg, num_sample, k, module):
     data = agg.data
     num_data = data.size
+    max_data = module.max(data[module.isfinite(data)])
+    if module == cupy:
+        max_data = max_data.get()
 
     if num_sample is not None and num_sample < num_data:
         # randomly select sample from the whole dataset
         # create a pseudo random number generator
-        generator = RandomState(1234567890)
-        idx = module.linspace(
+        # Note: cupy and nupy generate different random numbers
+        # use numpy.random to ensure the same result
+        generator = np.random.RandomState(1234567890)
+        idx = np.linspace(
             0, data.size, data.size, endpoint=False, dtype=module.uint32
         )
         generator.shuffle(idx)
@@ -582,6 +669,7 @@ def _run_natural_break(agg, num_sample, k, module):
     else:
         centroids = _run_jenks(sample_data, k, module)
         bins = module.array(centroids[1:])
+        bins[-1] = max_data
 
     out = _bin(agg, bins, module.arange(uvk))
     return out
@@ -628,6 +716,7 @@ def natural_breaks(agg: xr.DataArray,
     -------
     natural_breaks() works with numpy backed xarray DataArray.
     .. sourcecode:: python
+
         >>> import numpy as np
         >>> import xarray as xr
         >>> from xrspatial.classify import natural_breaks
@@ -654,6 +743,7 @@ def natural_breaks(agg: xr.DataArray,
 
     natural_breaks() works with cupy backed xarray DataArray.
     .. sourcecode:: python
+
         >>> import cupy
         >>> agg_cupy = xr.DataArray(cupy.asarray(elevation))
         >>> cupy_natural_breaks = natural_breaks(agg_cupy)
@@ -695,6 +785,8 @@ def _run_equal_interval(agg, k, module):
         inf = np.inf
 
     data = module.where(data == inf, nan, data)
+    data = module.where(data == -inf, nan, data)
+
     max_data = module.nanmax(data)
     min_data = module.nanmin(data)
     if module == cupy:
@@ -750,6 +842,7 @@ def equal_interval(agg: xr.DataArray,
     Examples
     --------
     .. sourcecode:: python
+
         >>> import numpy as np
         >>> import xarray as xr
         >>> from xrspatial.classify import equal_interval
