@@ -1,16 +1,12 @@
-from functools import partial
-
 import re
+from functools import partial
 
 import numpy as np
 import xarray as xr
+from numba import cuda, jit, prange
 
-from numba import cuda, float32, prange, jit
-
-from xrspatial.utils import cuda_args
-from xrspatial.utils import get_dataarray_resolution
-from xrspatial.utils import not_implemented_func
-from xrspatial.utils import ArrayTypeFunctionMapping
+from xrspatial.utils import (ArrayTypeFunctionMapping, cuda_args, get_dataarray_resolution,
+                             not_implemented_func)
 
 # 3rd-party
 try:
@@ -100,6 +96,7 @@ def calc_cellsize(raster):
     Examples
     --------
     .. sourcecode:: python
+
         >>> import numpy as np
         >>> import xarray as xr
         >>> h, w = 100, 200
@@ -297,7 +294,7 @@ def _convolve_2d_numpy(data, kernel):
     wkx = nkx // 2
     wky = nky // 2
 
-    out = np.zeros(data.shape, dtype=float32)
+    out = np.zeros(data.shape, dtype=np.float32)
     out[:] = np.nan
     for i in prange(wkx, nx-wkx):
         iimin = max(i - wkx, 0)
@@ -417,6 +414,7 @@ def convolution_2d(agg, kernel, name='convolution_2d'):
     --------
     convolution_2d() works with NumPy backed DataArray.
     .. sourcecode:: python
+
         >>> import numpy as np
         >>> import xarray as xr
         >>> from xrspatial.convolution import circle_kernel
@@ -447,6 +445,7 @@ def convolution_2d(agg, kernel, name='convolution_2d'):
 
     convolution_2d() works with Dask with NumPy backed DataArray.
     .. sourcecode:: python
+
         >>> from xrspatial.convolution import annulus_kernel
         >>> kernel = annulus_kernel(1, 1, 1.5, 0.5)
         >>> kernel
@@ -474,6 +473,7 @@ def convolution_2d(agg, kernel, name='convolution_2d'):
 
     convolution_2d() works with CuPy backed DataArray.
     .. sourcecode:: python
+
         >>> from xrspatial.convolution import custom_kernel
         >>> kernel = custom_kernel(np.array([
         ...    [1, 0, 0],
