@@ -1,7 +1,6 @@
 # std lib
 from functools import partial
-from typing import Union
-from typing import Optional
+from typing import Optional, Union
 
 # 3rd-party
 try:
@@ -11,18 +10,13 @@ except ImportError:
         ndarray = False
 
 import dask.array as da
-
-from numba import cuda
-
 import numpy as np
 import xarray as xr
+from numba import cuda
 
 # local modules
-from xrspatial.utils import cuda_args
-from xrspatial.utils import get_dataarray_resolution
-from xrspatial.utils import ngjit
-from xrspatial.utils import not_implemented_func
-from xrspatial.utils import ArrayTypeFunctionMapping
+from xrspatial.utils import (ArrayTypeFunctionMapping, cuda_args, get_dataarray_resolution, ngjit,
+                             not_implemented_func)
 
 
 @ngjit
@@ -125,6 +119,7 @@ def curvature(agg: xr.DataArray,
     --------
     Curvature works with NumPy backed xarray DataArray
     .. sourcecode:: python
+
         >>> import numpy as np
         >>> import xarray as xr
         >>> from xrspatial import curvature
@@ -144,6 +139,7 @@ def curvature(agg: xr.DataArray,
 
     Curvature works with Dask with NumPy backed xarray DataArray
     .. sourcecode:: python
+
         >>> convex_data = np.array([
             [0, 0, 0, 0, 0],
             [0, 0, 0, 0, 0],
@@ -179,6 +175,7 @@ def curvature(agg: xr.DataArray,
 
     Curvature works with CuPy backed xarray DataArray.
     .. sourcecode:: python
+
         >>> import cupy
         >>> concave_data = np.array([
             [0, 0, 0, 0, 0],
