@@ -1,12 +1,11 @@
 from math import sqrt
 
 import dask.array as da
-from numba import prange
 import numpy as np
 import xarray as xr
+from numba import prange
 
-from xrspatial.utils import ngjit, get_dataarray_resolution
-
+from xrspatial.utils import get_dataarray_resolution, ngjit
 
 EUCLIDEAN = 0
 GREAT_CIRCLE = 1
@@ -60,6 +59,7 @@ def euclidean_distance(x1: float, x2: float, y1: float, y2: float) -> float:
     Examples
     --------
     .. sourcecode:: python
+
         >>> # Imports
         >>> from xrspatial import euclidean_distance
         >>> point_a = (142.32, 23.23)
@@ -108,6 +108,7 @@ def manhattan_distance(x1: float, x2: float, y1: float, y2: float) -> float:
     Examples
     --------
     .. sourcecode:: python
+
         >>> from xrspatial import manhattan_distance
         >>> point_a = (142.32, 23.23)
         >>> point_b = (312.54, 432.01)
@@ -160,6 +161,7 @@ def great_circle_distance(
     Examples
     --------
     .. sourcecode:: python
+
         >>> from xrspatial import great_circle_distance
         >>> point_a = (123.2, 82.32)
         >>> point_b = (178.0, 65.09)
@@ -713,6 +715,7 @@ def proximity(
     Examples
     --------
     .. sourcecode:: python
+
         >>> import numpy as np
         >>> import xarray as xr
         >>> data = np.array([
@@ -845,6 +848,7 @@ def allocation(
     Examples
     --------
     .. sourcecode:: python
+
         >>> import numpy as np
         >>> import xarray as xr
         >>> data = np.array([
@@ -981,6 +985,7 @@ def direction(
     Examples
     --------
     .. sourcecode:: python
+
         >>> import numpy as np
         >>> import xarray as xr
         >>> data = np.array([
