@@ -1,14 +1,12 @@
-import pytest
 import numpy as np
+import pytest
 
 from xrspatial import curvature
+from xrspatial.tests.general_checks import (assert_numpy_equals_cupy,
+                                            assert_numpy_equals_dask_numpy, create_test_raster,
+                                            general_output_checks)
 from xrspatial.utils import doesnt_have_cuda
 
-from xrspatial.tests.general_checks import create_test_raster
-from xrspatial.tests.general_checks import assert_numpy_equals_dask_numpy
-from xrspatial.tests.general_checks import assert_numpy_equals_cupy
-from xrspatial.tests.general_checks import general_output_checks
-
 
 @pytest.fixture
 def flat_surface(size, dtype):
