@@ -1,20 +1,14 @@
+import dask.array as da
+import numpy as np
 import pytest
 import xarray as xr
-import numpy as np
-
-import dask.array as da
-
-from xrspatial.utils import doesnt_have_cuda
-from xrspatial.utils import ngjit
 
 from xrspatial import mean
-from xrspatial.focal import hotspots, apply, focal_stats
-from xrspatial.convolution import (
-    convolve_2d, circle_kernel, annulus_kernel
-)
-
-from xrspatial.tests.general_checks import create_test_raster
-from xrspatial.tests.general_checks import general_output_checks
+from xrspatial.convolution import (annulus_kernel, calc_cellsize, circle_kernel, convolution_2d,
+                                   convolve_2d, custom_kernel)
+from xrspatial.focal import apply, focal_stats, hotspots
+from xrspatial.tests.general_checks import create_test_raster, general_output_checks
+from xrspatial.utils import doesnt_have_cuda, ngjit
 
 
 def _do_sparse_array(data_array):
@@ -140,6 +134,18 @@ def convolution_kernel_annulus_2_2_1():
     return expected_result
 
 
+def test_kernel_custom_kernel_invalid_type():
+    kernel = [1, 0, 0]  # only arrays are accepted, not lists
+    with pytest.raises(ValueError):
+        custom_kernel(kernel)
+
+
+def test_kernel_custom_kernel_invalid_shape():
+    kernel = np.ones((4, 6))
+    with pytest.raises(ValueError):
+        custom_kernel(kernel)
+
+
 def test_kernel(kernel_circle_1_1_1, kernel_annulus_2_2_2_1):
     kernel_circle = circle_kernel(1, 1, 1)
     assert isinstance(kernel_circle, np.ndarray)
@@ -183,21 +189,21 @@ def test_convolution_dask_numpy(
     kernel_annulus_2_2_2_1,
     convolution_kernel_annulus_2_2_1
 ):
-    dask_data = da.from_array(convolve_2d_data, chunks=(3, 3))
+    dask_agg = create_test_raster(convolve_2d_data, backend='dask+numpy')
     kernel_custom = np.ones((1, 1))
-    result_kernel_custom = convolve_2d(dask_data, kernel_custom)
-    assert isinstance(result_kernel_custom, da.Array)
+    result_kernel_custom = convolution_2d(dask_agg, kernel_custom)
+    assert isinstance(result_kernel_custom.data, da.Array)
     # kernel is [[1]], thus the result equals input data
     np.testing.assert_allclose(result_kernel_custom.compute(), convolve_2d_data, equal_nan=True)
 
-    result_kernel_circle = convolve_2d(dask_data, kernel_circle_1_1_1)
-    assert isinstance(result_kernel_circle, da.Array)
+    result_kernel_circle = convolution_2d(dask_agg, kernel_circle_1_1_1)
+    assert isinstance(result_kernel_circle.data, da.Array)
     np.testing.assert_allclose(
         result_kernel_circle.compute(), convolution_kernel_circle_1_1_1, equal_nan=True
     )
 
-    result_kernel_annulus = convolve_2d(dask_data, kernel_annulus_2_2_2_1)
-    assert isinstance(result_kernel_annulus, da.Array)
+    result_kernel_annulus = convolution_2d(dask_agg, kernel_annulus_2_2_2_1)
+    assert isinstance(result_kernel_annulus.data, da.Array)
     np.testing.assert_allclose(
         result_kernel_annulus.compute(), convolution_kernel_annulus_2_2_1, equal_nan=True
     )
@@ -237,10 +243,22 @@ def test_2d_convolution_gpu(
         da.from_array(cupy.asarray(convolve_2d_data), chunks=(3, 3))
     )
     with pytest.raises(NotImplementedError) as e_info:
-        convolve_2d(dask_cupy_agg.data, kernel_custom)
+        convolution_2d(dask_cupy_agg, kernel_custom)
         assert e_info
 
 
+def test_calc_cellsize_unit_input_attrs(convolve_2d_data):
+    agg = create_test_raster(convolve_2d_data, attrs={'res': 1, 'unit': 'km'})
+    cellsize = calc_cellsize(agg)
+    assert cellsize == (1000, 1000)
+
+
+def test_calc_cellsize_no_attrs(convolve_2d_data):
+    agg = create_test_raster(convolve_2d_data)
+    cellsize = calc_cellsize(agg)
+    assert cellsize == (1, 1)
+
+
 @pytest.fixture
 def data_apply():
     data = np.array([[0, 1, 2, 3, 4, 5],
@@ -389,6 +407,15 @@ def data_hotspots():
     return data, kernel, expected_result
 
 
+def test_hotspots_zero_global_std():
+    data = np.zeros((10, 20))
+    agg = create_test_raster(data)
+    kernel = np.zeros((3, 3))
+    msg = "Standard deviation of the input raster values is 0."
+    with pytest.raises(ZeroDivisionError, match=msg):
+        hotspots(agg, kernel)
+
+
 def test_hotspots_numpy(data_hotspots):
     data, kernel, expected_result = data_hotspots
     numpy_agg = create_test_raster(data)
