@@ -1,20 +1,17 @@
-import pytest
-
-import numpy as np
-import pandas as pd
-import xarray as xr
 import dask.array as da
 import dask.dataframe as dd
+import numpy as np
+import pandas as pd
+import pytest
+import xarray as xr
 
-from xrspatial import zonal_stats as stats
+from xrspatial import crop, suggest_zonal_canvas, trim
 from xrspatial import zonal_apply as apply
 from xrspatial import zonal_crosstab as crosstab
-from xrspatial import suggest_zonal_canvas
-from xrspatial import trim
-from xrspatial import crop
-from xrspatial.zonal import regions
-
+from xrspatial import zonal_stats as stats
 from xrspatial.tests.general_checks import create_test_raster
+from xrspatial.utils import doesnt_have_cuda
+from xrspatial.zonal import regions
 
 
 @pytest.fixture
@@ -169,26 +166,35 @@ def check_results(backend, df_result, expected_results_dict):
         np.testing.assert_allclose(df_result[col], expected_results_dict[col])
 
 
-@pytest.mark.parametrize("backend", ['numpy', 'dask+numpy'])
+@pytest.mark.parametrize("backend", ['numpy', 'dask+numpy', 'cupy'])
 def test_default_stats(backend, data_zones, data_values_2d, result_default_stats):
+    if backend == 'cupy' and doesnt_have_cuda():
+        pytest.skip("CUDA Device not Available")
     df_result = stats(zones=data_zones, values=data_values_2d)
     check_results(backend, df_result, result_default_stats)
 
 
-@pytest.mark.parametrize("backend", ['numpy', 'dask+numpy'])
+@pytest.mark.parametrize("backend", ['numpy', 'dask+numpy', 'cupy'])
 def test_zone_ids_stats(backend, data_zones, data_values_2d, result_zone_ids_stats):
+    if backend == 'cupy' and doesnt_have_cuda():
+        pytest.skip("CUDA Device not Available")
     zone_ids, expected_result = result_zone_ids_stats
-    df_result = stats(zones=data_zones, values=data_values_2d, zone_ids=zone_ids)
+    df_result = stats(zones=data_zones, values=data_values_2d,
+                      zone_ids=zone_ids)
     check_results(backend, df_result, expected_result)
 
 
-@pytest.mark.parametrize("backend", ['numpy'])
+@pytest.mark.parametrize("backend", ['numpy', 'cupy'])
 def test_custom_stats(backend, data_zones, data_values_2d, result_custom_stats):
-    # ---- custom stats (NumPy only) ----
+    # ---- custom stats (NumPy and CuPy only) ----
+    if backend == 'cupy' and doesnt_have_cuda():
+        pytest.skip("CUDA Device not Available")
+
     custom_stats = {
         'double_sum': _double_sum,
         'range': _range,
     }
+
     nodata_values, zone_ids, expected_result = result_custom_stats
     df_result = stats(
         zones=data_zones, values=data_values_2d, stats_funcs=custom_stats,
@@ -219,7 +225,8 @@ def test_percentage_crosstab_2d(backend, data_zones, data_values_2d, result_perc
 @pytest.mark.parametrize("backend", ['numpy', 'dask+numpy'])
 def test_crosstab_3d(backend, data_zones, data_values_3d, result_crosstab_3d):
     layer, zone_ids, expected_result = result_crosstab_3d
-    df_result = crosstab(zones=data_zones, values=data_values_3d, zone_ids=zone_ids, layer=layer)
+    df_result = crosstab(zones=data_zones, values=data_values_3d,
+                         zone_ids=zone_ids, layer=layer)
     check_results(backend, df_result, expected_result)
 
 
@@ -243,7 +250,7 @@ def test_apply():
     def func(x):
         return 0
 
-    zones_val = np.zeros((3, 3), dtype=int)
+    zones_val = np.zeros((3, 3), dtype=np.int32)
     # define some zones
     zones_val[1] = 1
     zones_val[2] = 2
