@@ -1,14 +1,14 @@
-from math import atan, sqrt, fabs
+from math import atan, fabs
 from math import pi as PI
+from math import sqrt
 from typing import Union
 
 import numpy as np
-from .utils import has_cupy, is_cupy_array, ngjit
-from .gpu_rtx import has_rtx
-
-
 import xarray
 
+from .gpu_rtx import has_rtx
+from .utils import has_cupy, is_cupy_array, ngjit
+
 E_ROW_ID = 0
 E_COL_ID = 1
 E_TYPE_ID = 2
@@ -1039,14 +1039,17 @@ def _calculate_angle(event_x, event_y, viewpoint_x, viewpoint_y):
     if event_x == viewpoint_x and event_y == viewpoint_y:
         return 0
 
-    # Calculate angle between (x1, y1) and (x2, y2)
-    ang = atan(fabs(event_y - viewpoint_y) / fabs(event_x - viewpoint_x))
-
-    # M_PI is defined in math.h to represent 3.14159...
     if viewpoint_y == event_y and event_x > viewpoint_x:
         # between 1st and 4th quadrant
         return 0
 
+    if viewpoint_x > event_x and viewpoint_y == event_y:
+        # between 1st and 3rd quadrant
+        return PI
+
+    # Calculate angle between (x1, y1) and (x2, y2)
+    ang = atan(fabs(event_y - viewpoint_y) / fabs(event_x - viewpoint_x))
+
     if event_x > viewpoint_x and event_y < viewpoint_y:
         # first quadrant
         return ang
@@ -1055,10 +1058,6 @@ def _calculate_angle(event_x, event_y, viewpoint_x, viewpoint_y):
         # 2nd quadrant
         return PI - ang
 
-    if viewpoint_x > event_x and viewpoint_y == event_y:
-        # between 1st and 3rd quadrant
-        return PI
-
     if viewpoint_x > event_x and viewpoint_y < event_y:
         # 3rd quadrant
         return PI + ang
